@@ -2,7 +2,7 @@ package t::Memcached::Mock;
 
 use strict;
 use warnings;
-use Memcached::Client::Log;
+use Memcached::Client::Log qw{DEBUG LOG};
 use Module::Load;
 
 sub new {
@@ -15,7 +15,7 @@ sub new {
     $self->{selector}->set_servers ($args{servers});
     $self->{version} = $args{version};
     map {$self->{servers}->{(ref $_ ? $_->[0] : $_)} = {}} @{$args{servers}};
-    DEBUG "Mock cluster is %s", $self;
+    $self->log ("Mock cluster is %s", $self) if DEBUG;
     $self;
 }
 
@@ -36,7 +36,7 @@ sub add {
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return 0 unless (defined $self->{servers}->{$server});
-    DEBUG "M: add: %s - %s - %s", $server, $index, $value;
+    $self->log ("add: %s - %s - %s", $server, $index, $value) if DEBUG;
     return 0 if (defined $self->{servers}->{$server}->{$index});
     $self->{servers}->{$server}->{$index} = $value;
     return 1;
@@ -47,7 +47,8 @@ sub add_multi {
     my (%rv);
     for my $tuple (@{$tuples}) {
         my ($key) = @{$tuple};
-        $rv{$key} = $self->add (@{$tuple});
+        my $value = $self->add (@{$tuple});
+        $rv{$key} = $value if defined $value;
     }
     return \%rv;
 }
@@ -58,7 +59,7 @@ sub append {
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return 0 unless (defined $self->{servers}->{$server});
-    DEBUG "M: append: %s - %s - %s", $server, $index, $value;
+    $self->log ("append: %s - %s - %s", $server, $index, $value) if DEBUG;
     return 0 unless (defined $self->{servers}->{$server}->{$index});
     $self->{servers}->{$server}->{$index} .= $value;
     return 1;
@@ -69,19 +70,24 @@ sub append_multi {
     my (%rv);
     for my $tuple (@{$tuples}) {
         my ($key) = @{$tuple};
-        $rv{$key} = $self->append (@{$tuple});
+        my $value = $self->append (@{$tuple});
+        $rv{$key} = $value if defined $value;
     }
     return \%rv;
 }
 
+sub connect {
+    return 1;
+}
+
 sub decr {
     my ($self, $key, $delta, $initial) = @_;
-    $delta //= 1;
+    $delta = 1 unless defined $delta;
     return unless (defined $key and (ref $key and $key->[0] and $key->[1]) || (length $key and -1 == index $key, " "));
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return unless (defined $self->{servers}->{$server});
-    DEBUG "M: decr: %s - %s - %s", $server, $index, $delta;
+    $self->log ("decr: %s - %s - %s", $server, $index, $delta) if DEBUG;
     if (defined $self->{servers}->{$server}->{$index}) {
         if ($self->{servers}->{$server}->{$index} =~ m/^\d+$/) {
             $delta = $self->{servers}->{$server}->{$index} if ($delta > $self->{servers}->{$server}->{$index});
@@ -100,7 +106,8 @@ sub decr_multi {
     my (%rv);
     for my $tuple (@{$tuples}) {
         my ($key) = @{$tuple};
-        $rv{$key} = $self->decr (@{$tuple});
+        my $value = $self->decr (@{$tuple});
+        $rv{$key} = $value if defined $value;
     }
     return \%rv;
 }
@@ -111,7 +118,7 @@ sub delete {
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return 0 unless (defined $self->{servers}->{$server});
-    DEBUG "M: delete: %s - %s", $server, $index;
+    $self->log ("delete: %s - %s", $server, $index) if DEBUG;
     return 0 unless (defined $self->{servers}->{$server}->{$index});
     delete $self->{servers}->{$server}->{$index};
     return 1;
@@ -121,7 +128,8 @@ sub delete_multi {
     my ($self, @keys) = @_;
     my (%rv);
     for my $key (@keys) {
-        $rv{$key} = $self->delete ($key);
+        my $value = $self->delete ($key);
+        $rv{$key} = $value if defined $value;
     }
     return \%rv;
 }
@@ -129,7 +137,7 @@ sub delete_multi {
 sub flush_all {
     my ($self) = @_;
     map {
-        DEBUG "M: flush_all: %s", $_;
+        $self->log ("flush_all: %s", $_) if DEBUG;
         $self->{servers}->{$_} = {};
     } keys %{$self->{servers}};
     return {map {$_ => 1} keys %{$self->{servers}}};
@@ -141,34 +149,38 @@ sub get {
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return unless (defined $self->{servers}->{$server});
-    DEBUG "M: get: %s - %s", $server, $index;
-    return $self->{servers}->{$server}->{$index};
+    $self->log ("get: %s - %s", $server, $index) if DEBUG;
+    if (length $index > 250) {
+        return undef;
+    } else {
+        return $self->{servers}->{$server}->{$index};
+    }
 }
 
 sub get_multi {
-    my ($self, $keys) = @_;
-    return {} unless (defined $keys and ref $keys eq "ARRAY" and @{$keys});
+    my ($self, @keys) = @_;
+    return {} unless (@keys);
     my %rv;
-    for my $key (@{$keys}) {
+    for my $key (@keys) {
         next unless (defined $key and (ref $key and $key->[0] and $key->[1]) || (length $key and -1 == index $key, " "));
         my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or next;
         my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
         next unless (defined $self->{servers}->{$server});
-        DEBUG "M: get: %s - %s", $server, $index;
+        $self->log ("get: %s - %s", $server, $index) if DEBUG;
         next unless (defined $self->{servers}->{$server}->{$index});
-        $rv{ref $key ? $key->[1] : $key} = $self->{servers}->{$server}->{$index};
+        $rv{ref $key ? $key->[1] : $key} = length $index > 250 ? undef : $self->{servers}->{$server}->{$index};
     }
     return \%rv;
 }
 
 sub incr {
     my ($self, $key, $delta, $initial) = @_;
-    $delta //= 1;
+    $delta = 1 unless defined $delta;
     return unless (defined $key and (ref $key and $key->[0] and $key->[1]) || (length $key and -1 == index $key, " "));
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return unless (defined $self->{servers}->{$server});
-    DEBUG "M: incr: %s - %s - %s", $server, $index, $delta;
+    $self->log ("incr: %s - %s - %s", $server, $index, $delta) if DEBUG;
     if (defined $self->{servers}->{$server}->{$index}) {
         if ($self->{servers}->{$server}->{$index} =~ m/^\d+$/) {
             $self->{servers}->{$server}->{$index} += $delta;
@@ -186,7 +198,8 @@ sub incr_multi {
     my (%rv);
     for my $tuple (@{$tuples}) {
         my ($key) = @{$tuple};
-        $rv{$key} = $self->incr (@{$tuple});
+        my $value = $self->incr (@{$tuple});
+        $rv{$key} = $value if defined $value;
     }
     return \%rv;
 }
@@ -204,7 +217,7 @@ sub prepend {
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return 0 unless (defined $self->{servers}->{$server});
-    DEBUG "M: prepend: %s - %s - %s", $server, $index, $value;
+    $self->log ("prepend: %s - %s - %s", $server, $index, $value) if DEBUG;
     return 0 unless (defined $self->{servers}->{$server}->{$index});
     $self->{servers}->{$server}->{$index} = $value . $self->{servers}->{$server}->{$index};
     return 1;
@@ -215,7 +228,8 @@ sub prepend_multi {
     my (%rv);
     for my $tuple (@{$tuples}) {
         my ($key) = @{$tuple};
-        $rv{$key} = $self->prepend (@{$tuple});
+        my $value = $self->prepend (@{$tuple});
+        $rv{$key} = $value if defined $value;
     }
     return \%rv;
 }
@@ -226,7 +240,7 @@ sub replace {
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return 0 unless (defined $self->{servers}->{$server});
-    DEBUG "M: replace: %s - %s - %s", $server, $index, $value;
+    $self->log ("replace: %s - %s - %s", $server, $index, $value) if DEBUG;
     return 0 unless (defined $self->{servers}->{$server}->{$index});
     $self->{servers}->{$server}->{$index} = $value;
     return 1;
@@ -237,7 +251,8 @@ sub replace_multi {
     my (%rv);
     for my $tuple (@{$tuples}) {
         my ($key) = @{$tuple};
-        $rv{$key} = $self->replace (@{$tuple});
+        my $value = $self->replace (@{$tuple});
+        $rv{$key} = $value if defined $value;
     }
     return \%rv;
 }
@@ -248,9 +263,13 @@ sub set {
     my $server = $self->{selector}->get_server ($key, $self->{hash_namespace} ? $self->{namespace} : "") or return;
     my $index = $self->{namespace} . (ref $key ? $key->[1] : $key);
     return 0 unless (defined $self->{servers}->{$server});
-    DEBUG "M: set: %s - %s - %s", $server, $index, $value;
-    $self->{servers}->{$server}->{$index} = $value;
-    return 1;
+    $self->log ("set: %s - %s - %s", $server, $index, $value) if DEBUG;
+    if (length $index > 250) {
+        return 0;
+    } else {
+        $self->{servers}->{$server}->{$index} = $value;
+        return 1;
+    }
 }
 
 sub set_multi {
@@ -258,7 +277,8 @@ sub set_multi {
     my (%rv);
     for my $tuple (@{$tuples}) {
         my ($key) = @{$tuple};
-        $rv{$key} = $self->set (@{$tuple});
+        my $value = $self->set (@{$tuple});
+        $rv{$key} = $value if defined $value;
     }
     return \%rv;
 }
@@ -289,16 +309,26 @@ sub stop {
     my ($self, $server) = @_;
     delete $self->{servers}->{$server};
     # $self->{servers}->{$server} = undef;
-    DEBUG "Deleted %s, result %s", $server, $self;
+    $self->log ("Deleted %s, result %s", $server, $self) if DEBUG;
     return 1;
 }
 
 sub version {
     my ($self) = @_;
     return {map {
-        DEBUG "M: version: %s", $_;
+        $self->log ("version: %s", $_) if DEBUG;
         $_ => defined $self->{servers}->{$_} ? $self->{version} : undef
     } keys %{$self->{servers}}};
 }
 
+=method log
+
+=cut
+
+sub log {
+    my ($self, $format, @args) = @_;
+    LOG ("Mock> " . $format, @args);
+}
+
+
 1;
